<p align="center" style="background=#333">
    <img src="https://github.com/TechPenguineer/chem.py/blob/main/public/logo.png" width="300px">
    <h1 align="center">Chemistry in python</h1>
</p>

# Installation
```bat
pip install chemispy
```

# Usage

```py
from chemispy import *
```

### Atomic Number Query

```python
query.query_atomic_number(1)
```
*Return's the name of the element corresponding to the atomic number*

### Elements List

```python
print(query.list_types())
```
*Returns a list of all elements (Used mostly for debugging)*